"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultFileSaver = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const defaultFileSaver_config_1 = require("../config/defaultFileSaver.config");
/**
 * Default implementation of the IFileSaver interface.
 * This class is responsible for saving file data to the filesystem.
 *
 * @deprecated This class is deprecated. Use LocalFileSaver instead.
 * @see {@link LocalFileSaver}
 */
class DefaultFileSaver {
    /**
     * Constructs a new instance of the DefaultFileSaver class.
     * @param options - Optional configuration options for the file saver.
     */
    constructor(options) {
        this.options = options;
        this.options = { ...defaultFileSaver_config_1.DEFAULT_FILE_SAVER_OPTION, ...options };
    }
    /**
     * Saves the provided file data to the specified file path.
     * Ensures the directory exists and writes the file buffer to the file path.
     * @param fileData - The file data to save.
     * @param context - The execution context, typically provided by NestJS.
     * @returns The file path where the file was saved.
     */
    save(fileData, context) {
        // Determine the directory where the file will be saved.
        const directory = this.options.customDirectory
            ? this.options.customDirectory(context, this.options.prefixDirectory)
            : this.options.prefixDirectory;
        // Construct the full file path, ensuring platform-independent path separators.
        const filePath = path_1.default
            .join(directory, fileData.fileNameFull)
            .replace(/\\/g, "/");
        // Ensure the directory exists, creating it recursively if necessary.
        if (!fs_1.default.existsSync(directory)) {
            fs_1.default.mkdirSync(directory, { recursive: true });
        }
        // Write the file buffer to the specified file path.
        fs_1.default.writeFileSync(filePath, fileData.buffer);
        // Return the file path where the file was saved.
        return filePath;
    }
}
exports.DefaultFileSaver = DefaultFileSaver;
//# sourceMappingURL=default.file-saver.js.map