import { ExecutionContext } from "@nestjs/common";
import { IFileSaver, ILocalFileSaverOptions } from "../interfaces/file.interface";
import { FileData } from "../classes/FileData";
/**
 * Default implementation of the IFileSaver interface.
 * This class is responsible for saving file data to the filesystem.
 */
export declare class LocalFileSaver implements IFileSaver {
    private readonly options?;
    /**
     * Constructs a new instance of the LocalFileSaver class.
     * @param options - Optional configuration options for the file saver.
     */
    constructor(options?: ILocalFileSaverOptions);
    /**
     * Saves the provided file data to the specified file path.
     * Ensures the directory exists and writes the file buffer to the file path.
     * @param fileData - The file data to save.
     * @param context - The execution context, typically provided by NestJS.
     * @param options - Optional configuration for the file path and directory.
     * @returns The file path where the file was saved.
     */
    save(fileData: FileData, context: ExecutionContext, options?: ILocalFileSaverOptions): string;
}
