import { ExecutionContext } from "@nestjs/common";
import { FileData } from "../classes/FileData";
import { IFileSaver, IS3FileSaverOptions, S3FileDataOptions } from "../interfaces/file.interface";
export declare class S3FileSaver implements IFileSaver {
    private readonly fileUploadOptions;
    private readonly s3Client;
    /**
     * Initializes a new instance of the S3FileSaver class.
     * Sets up the S3 client using the provided configuration options.
     * @param fileUploadOptions - configuration options for S3 file uploads.
     */
    constructor(fileUploadOptions: IS3FileSaverOptions);
    /**
     * Saves the provided file data to an S3 bucket.
     * Constructs the S3 object parameters and sends a PutObjectCommand to S3.
     * @param fileData - The file data to be saved, including the buffer and metadata.
     * @param context - The execution context, typically provided by NestJS.
     * @param options - Optional S3-specific file data options, such as bucket and additional parameters.
     * @returns A promise that resolves to the URL of the saved file in S3.
     * @throws InternalServerErrorException if the S3 bucket is not specified.
     */
    save(fileData: FileData, context: ExecutionContext, options?: S3FileDataOptions): Promise<string>;
}
