"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const class_validator_1 = require("class-validator");
const hasMimeType_decorator_1 = require("../../validators/hasMimeType.decorator");
const FileData_1 = require("../../classes/FileData");
class TestSingleFileClass {
}
__decorate([
    (0, class_validator_1.IsDefined)(),
    (0, hasMimeType_decorator_1.HasMimeType)(["image/jpeg", "image/png"]),
    __metadata("design:type", FileData_1.FileData)
], TestSingleFileClass.prototype, "file", void 0);
class TestSingleFileOptionalClass {
}
__decorate([
    (0, class_validator_1.IsOptional)(),
    (0, hasMimeType_decorator_1.HasMimeType)(["image/*"]),
    __metadata("design:type", FileData_1.FileData)
], TestSingleFileOptionalClass.prototype, "file", void 0);
class TestingGenericFileClass {
}
__decorate([
    (0, class_validator_1.IsDefined)(),
    (0, hasMimeType_decorator_1.HasMimeType)(["image/*"]),
    __metadata("design:type", FileData_1.FileData)
], TestingGenericFileClass.prototype, "file", void 0);
class TestMultipleFilesClass {
}
__decorate([
    (0, class_validator_1.IsDefined)(),
    (0, hasMimeType_decorator_1.HasMimeType)(["image/jpeg", "image/png"], { each: true }),
    __metadata("design:type", Array)
], TestMultipleFilesClass.prototype, "files", void 0);
describe("HasMimeType", () => {
    const createFileData = (mimetype) => {
        return new FileData_1.FileData("image.png", "image.png", "image.png", "7bit", mimetype, "png", 10000, "hash", Buffer.from("test"));
    };
    it("should validate single file with allowed mimetype", async () => {
        const instance = new TestSingleFileClass();
        instance.file = createFileData("image/jpeg");
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
    it("should validate single file with allowed generic mimetype", async () => {
        const instance = new TestingGenericFileClass();
        instance.file = createFileData("image/jpeg");
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
    it("should fail validation single file with allowed generic mimetype", async () => {
        const instance = new TestingGenericFileClass();
        instance.file = createFileData("video/mp4");
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("HasMimeTypeConstraint");
    });
    it("should success validation optional file with no file", async () => {
        const instance = new TestSingleFileOptionalClass();
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
    it("should fail validation optional file with wrong mimetype", async () => {
        const instance = new TestSingleFileOptionalClass();
        instance.file = createFileData("application/pdf");
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("HasMimeTypeConstraint");
    });
    it("should fail validation for single file with disallowed mimetype", async () => {
        const instance = new TestSingleFileClass();
        instance.file = createFileData("application/pdf");
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("HasMimeTypeConstraint");
    });
    it("should validate array of files with allowed mime types", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [
            createFileData("image/jpeg"),
            createFileData("image/png"),
        ];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
    it("should fail validation for array of files with one disallowed mimetype", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [
            createFileData("image/jpeg"),
            createFileData("application/pdf"),
        ];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("HasMimeTypeConstraint");
    });
    it("should fail validation for empty mimetype in single file", async () => {
        const instance = new TestSingleFileClass();
        instance.file = createFileData("");
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("HasMimeTypeConstraint");
    });
    it("should fail validation for null mimetype in single file", async () => {
        const instance = new TestSingleFileClass();
        instance.file = createFileData(null);
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("HasMimeTypeConstraint");
    });
    it("should validate an empty array for each option", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
});
//# sourceMappingURL=hasMimetype.spec.js.map