"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const class_validator_1 = require("class-validator");
const file_interface_1 = require("../../interfaces/file.interface");
const isFileData_decorator_1 = require("../../validators/isFileData.decorator");
const FileData_1 = require("../../classes/FileData");
class TestSingleFileClass {
}
__decorate([
    (0, class_validator_1.IsDefined)(),
    (0, isFileData_decorator_1.IsFileData)(),
    __metadata("design:type", FileData_1.FileData)
], TestSingleFileClass.prototype, "file", void 0);
class TestMultipleFilesClass {
}
__decorate([
    (0, class_validator_1.IsDefined)(),
    (0, isFileData_decorator_1.IsFileData)({ each: true }),
    __metadata("design:type", Array)
], TestMultipleFilesClass.prototype, "files", void 0);
describe("IsFileData", () => {
    const createFileDataConstant = () => {
        return new FileData_1.FileData("image.png", "image.png", "image.png", "7bit", file_interface_1.MimeType["image/png"], "png", 10000, "hash", Buffer.from("test"));
    };
    const createFileData = (mimetype) => ({
        originalFileName: "testFile.jpg",
        fileName: "testFile",
        fileNameFull: `testFile.${mimetype?.split("/")[1] || "file"}`,
        encoding: "7bit",
        mimetype: mimetype,
        fileExtension: mimetype?.split("/")[1] || "",
        fileSize: 1024,
        buffer: Buffer.from("test content"),
        save: () => {
            return "file saved";
        },
    });
    it("should validate single file with allowed mimetype", async () => {
        const instance = new TestSingleFileClass();
        instance.file = createFileDataConstant();
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
    it("should fail validation for single file with disallowed mimetype", async () => {
        const instance = new TestSingleFileClass();
        instance.file = createFileData("application/pdf");
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("IsFileDataConstraint");
    });
    it("should validate array of files with allowed mime types", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [createFileDataConstant(), createFileDataConstant()];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
    it("should fail validation for array of files with one disallowed mimetype", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [
            createFileData("image/jpeg"),
            createFileData("application/pdf"),
        ];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("IsFileDataConstraint");
    });
    it("should validate an empty array for each option", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
});
//# sourceMappingURL=isFileData.spec.js.map