"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const class_validator_1 = require("class-validator");
const minFileSize_decorator_1 = require("../../validators/minFileSize.decorator");
const FileData_1 = require("../../classes/FileData");
// Test class for a single file
class TestSingleFileClass {
}
__decorate([
    (0, class_validator_1.IsDefined)(),
    (0, minFileSize_decorator_1.MinFileSize)(10000),
    __metadata("design:type", FileData_1.FileData)
], TestSingleFileClass.prototype, "file", void 0);
// Test class for multiple files
class TestMultipleFilesClass {
}
__decorate([
    (0, class_validator_1.IsDefined)(),
    (0, minFileSize_decorator_1.MinFileSize)(10000, { each: true }),
    __metadata("design:type", Array)
], TestMultipleFilesClass.prototype, "files", void 0);
describe("MaxFileSize", () => {
    const createFileData = (fileSize) => {
        return new FileData_1.FileData("image.png", "image.png", "image.png", "7bit", "image/jpeg", "png", fileSize, "hash", Buffer.from("test"));
    };
    it("should validate single file within max file size", async () => {
        const instance = new TestSingleFileClass();
        instance.file = createFileData(90000);
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
    it("should fail validation for single file exceeding max file size", async () => {
        const instance = new TestSingleFileClass();
        instance.file = createFileData(1500);
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("MinFileSizeConstraint");
    });
    it("should validate multiple files within max file size", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [createFileData(50000), createFileData(40000)];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
    it("should fail validation for multiple files with one exceeding max file size", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [createFileData(5000), createFileData(15000)];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("MinFileSizeConstraint");
    });
    it("should fail validation for multiple files with all exceeding max file size", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [createFileData(1500), createFileData(2000)];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBeGreaterThan(0);
        expect(errors[0].constraints).toHaveProperty("MinFileSizeConstraint");
    });
    it("should validate an empty array for each option", async () => {
        const instance = new TestMultipleFilesClass();
        instance.files = [];
        const errors = await (0, class_validator_1.validate)(instance);
        expect(errors.length).toBe(0);
    });
});
//# sourceMappingURL=minFileSize.spec.js.map