"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HasMimeType = HasMimeType;
const class_validator_1 = require("class-validator");
/**
 * Custom validator constraint to check if the mimetype of a FileData object matches the specified types.
 */
let HasMimeTypeConstraint = class HasMimeTypeConstraint {
    /**
     * Validates if the mimetype of the provided FileData object matches the specified types.
     * @param value The FileData object to validate.
     * @param args The validation arguments containing the constraints and options.
     * @returns A boolean indicating whether the mimetype matches the specified types.
     */
    validate(value, args) {
        const [mimeType, option] = args.constraints;
        if (option?.each && Array.isArray(value)) {
            return value.every((item) => this.matchesWildcard(mimeType, item.mimetype));
        }
        else {
            return this.matchesWildcard(mimeType, value?.mimetype);
        }
    }
    /**
     * Checks if a mimetype matches a wildcard type.
     * @param mimeType An array of allowed mimetypes (or a single mimetype).
     * @param type The mimetype to check against the allowed types.
     * @returns A boolean indicating whether the mimetype matches any of the allowed types.
     */
    matchesWildcard(mimeType, type) {
        return mimeType.some((allowedType) => {
            if (allowedType?.endsWith("/*")) {
                return type?.startsWith(allowedType.slice(0, -2));
            }
            return type === allowedType;
        });
    }
    /**
     * Generates the default error message for the HasMimeType constraint.
     * @param args The validation arguments containing the constraints and options.
     * @returns The default error message.
     */
    defaultMessage(args) {
        const [mimeType, option] = args.constraints;
        if (option?.each) {
            return `The mimetype of ${args.property} must be an array of ${mimeType}`;
        }
        else {
            return `The mimetype of ${args.property} must be an ${mimeType}`;
        }
    }
};
HasMimeTypeConstraint = __decorate([
    (0, class_validator_1.ValidatorConstraint)({ async: false })
], HasMimeTypeConstraint);
/**
 * Decorator that applies the HasMimeType constraint to the specified property.
 * @param mimeType The allowed mimetype(s) to validate against.
 * @param validationOptions The validation options.
 * @returns The decorator function.
 */
function HasMimeType(mimeType, validationOptions) {
    return (object, propertyName) => {
        (0, class_validator_1.registerDecorator)({
            target: object.constructor,
            propertyName: propertyName,
            options: validationOptions,
            constraints: [mimeType, validationOptions],
            validator: HasMimeTypeConstraint,
        });
    };
}
//# sourceMappingURL=hasMimeType.decorator.js.map