"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MinFileSize = MinFileSize;
const class_validator_1 = require("class-validator");
/**
 * Validator constraint to check if the file size is above the minimum limit.
 */
let MinFileSizeConstraint = class MinFileSizeConstraint {
    /**
     * Validates if the file size is above the minimum limit.
     * @param value - The FileData object to validate.
     * @param args - The validation arguments containing constraints and other metadata.
     * @returns `true` if the file size is above the limit, otherwise `false`.
     */
    validate(value, args) {
        const [minSize, options] = args.constraints;
        if (options?.each && Array.isArray(value)) {
            return value.every((item) => item.fileSize > minSize);
        }
        else {
            return value?.fileSize > minSize;
        }
    }
    /**
     * Provides a default error message if the validation fails.
     * @param args - The validation arguments containing constraints and other metadata.
     * @returns The default error message.
     */
    defaultMessage(args) {
        const [minSize] = args.constraints;
        return `The file ${args.property} minimum file size is ${minSize} bytes`;
    }
};
MinFileSizeConstraint = __decorate([
    (0, class_validator_1.ValidatorConstraint)({ async: false })
], MinFileSizeConstraint);
/**
 * Decorator function to validate if the file size is above the minimum limit.
 * @param minSize - The minimum file size in bytes.
 * @param validationOptions - Optional validation options to customize the validation behavior.
 * @returns A property decorator function.
 */
function MinFileSize(minSize, validationOptions) {
    return (object, propertyName) => {
        (0, class_validator_1.registerDecorator)({
            target: object.constructor,
            propertyName: propertyName,
            options: validationOptions,
            constraints: [minSize, validationOptions],
            validator: MinFileSizeConstraint,
        });
    };
}
//# sourceMappingURL=minFileSize.decorator.js.map